@@ -1,10 +1,11 @@
 use 5.008001;
 use strict;
 use warnings;
+
 package Noisy;
 
 sub do_it {
-    warn "I am noisy"
+    warn "I am noisy";
 }
 
 sub with_newline {
